@@ -36,7 +36,10 @@ import platform
     # exr's are failing on my machine -matias
     'image/exr-hdr-weird/farm_sunset_1k.hdr',
     'image/exr-hdr-weird/limpopo_golf_course_1k.hdr',
-    'image/exr-hdr-weird/sample_640426.hdr'
+    'image/exr-hdr-weird/sample_640426.hdr',
+    
+    'photoshop/model_157142297.psd',
+    'illustrator/example.ai'
 ]])
 def test_visual_assets_batched(
         demo_assets: List[AssetModel],
@@ -52,26 +55,26 @@ def test_visual_assets_batched(
         assert asset.preview_images
         assert asset.tags
 
+@pytest.mark.parametrize('demo_file_name', [
+    'audio/Cymatics - Buildup Drums 19 - 140 BPM.wav',
+    'audio/Cymatics - Buildup Drums 20 - 140 BPM.wav',
+    'audio/Cymatics - Buildup Drums 24 - 150 BPM.wav',
+    'audio/Snap Sound Effect [ HD ].mp3',
+    'audio/item_purchase.ogg',
+])
+def test_audio_assets(
+        demo_asset: AssetModel,
+        backend: ShadeLocal,
+):
+    backend.models.enable_model('audio')
+    asset = wait_for_jobs(backend, [
+        Job.METADATA,
+        Job.AUDIO
+    ], [demo_asset])[0]
 
-# @pytest.mark.parametrize('demo_file_name', [
-#     'audio/Cymatics - Buildup Drums 19 - 140 BPM.wav',
-#     'audio/Cymatics - Buildup Drums 20 - 140 BPM.wav',
-#     'audio/Cymatics - Buildup Drums 24 - 150 BPM.wav',
-#     'audio/Snap Sound Effect [ HD ].mp3',
-#     'audio/item_purchase.ogg',
-# ])
-# def test_audio_assets(
-#         demo_asset: AssetModel,
-#         backend: ShadeLocal,
-# ):
-#     asset = wait_for_jobs(backend, [
-#         Job.METADATA,
-#         Job.AUDIO
-#     ], [demo_asset])[0]
-#
-#     # assert asset.size_bytes
-#     assert asset.tags
-#     assert asset.ai_indexed
+    # assert asset.size_bytes
+    assert asset.tags
+    assert asset.ai_indexed
 
 
 @pytest.mark.parametrize('demo_file_name', [
@@ -83,6 +86,8 @@ def test_text_assets(
         demo_asset: AssetModel,
         backend: ShadeLocal,
 ):
+    backend.models.enable_model('text')
+
     asset = wait_for_jobs(backend, [
         Job.METADATA,
         Job.TEXT
@@ -98,6 +103,8 @@ def test_facial_recognition_batched(
         demo_assets: List[AssetModel],
         backend: ShadeLocal,
 ):
+    backend.models.enable_model('facial')
+
     assets = wait_for_jobs(backend, [
         Job.METADATA,
         Job.FACIAL_RECOGNITION,
